<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="设备编号" prop="deviceNo">
        <el-input
          v-model="queryParams.deviceNo"
          placeholder="请输入设备编号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="设备名称" prop="deviceName">
        <el-input
          v-model="queryParams.deviceName"
          placeholder="请输入设备名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="设备IP地址" prop="deviceIpAddr">
        <el-input
          v-model="queryParams.deviceIpAddr"
          placeholder="请输入设备IP地址"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="设备状态" prop="deviceState">
        <el-select v-model="queryParams.deviceState" placeholder="请选择设备状态" clearable size="small">
          <el-option
            v-for="dict in dict.type.device_state"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['device:device:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['device:device:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['device:device:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['device:device:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="deviceList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="设备编号" align="center" prop="deviceNo"/>
      <el-table-column label="位置编号" align="center" prop="placeNumber"/>
      <el-table-column label="设备名称" align="center" prop="deviceName"/>
      <el-table-column label="设备初始化码" align="center" prop="deviceInitCode"/>
      <el-table-column label="设备IP地址" align="center" prop="deviceIpAddr"/>
      <el-table-column label="设备状态" align="center" prop="deviceState">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.device_state" :value="scope.row.deviceState"/>
        </template>
      </el-table-column>
      <el-table-column label="到期时间" align="center" prop="expirationDate" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.expirationDate, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center" prop="remark"/>
      <el-table-column label="机构代码" align="center" prop="deviceOrgId"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-user"
            @click="openBindingUsers(scope.row)"
          >绑定用户
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-postcard"
            @click="getDeviceUseNoList(scope.row)"
          >空开列表
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['device:device:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['device:device:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改device对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="50%" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-form-item label="设备名称" prop="deviceName">
          <el-input v-model="form.deviceName" placeholder="请输入设备名称"/>
        </el-form-item>
        <el-form-item label="设备初始化码" prop="deviceInitCode">
          <el-input v-model="form.deviceInitCode" placeholder="请输入设备初始化码"/>
        </el-form-item>
        <el-form-item label="设备IP地址" prop="deviceIpAddr">
          <el-input v-model="form.deviceIpAddr" placeholder="请输入设备IP地址"/>
        </el-form-item>
        <el-form-item label="设备地理位置" prop="deviceLocationAddr">
          <baidu-map-point v-model="form.deviceLocationAddr" :show-text="false"/>
        </el-form-item>
        <el-form-item label="设备状态">
          <el-radio-group v-model="form.deviceState">
            <el-radio
              v-for="dict in dict.type.device_state"
              :key="dict.value"
              :label="parseInt(dict.value)"
            >{{ dict.label }}
            </el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="到期时间" prop="expirationDate">
          <el-date-picker clearable size="small"
                          v-model="form.expirationDate"
                          type="date"
                          value-format="yyyy-MM-dd"
                          placeholder="选择到期时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="机构代码" prop="deviceOrgId">
          <el-input v-model="form.deviceOrgId" placeholder="请输入机构代码" disabled/>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" type="textarea" placeholder="请输入备注"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>


    <el-dialog title="绑定用户" v-dialogDrag :visible.sync="open1" width="80%" append-to-body>
      <el-row :gutter="20" class="mb8">
        <el-col :span="12">
          <el-tag type="success">可绑定</el-tag>
          <div style="height: 10px"></div>
          <el-table v-loading="loading1" :data="allUserList" @selection-change="handleSelectionChange">
            <el-table-column label="用户编号" align="center" prop="userName"/>
            <el-table-column label="用户名" align="center" prop="nickName"/>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
              <template slot-scope="scope">
                <el-button
                  size="mini"
                  type="text"
                  icon="el-icon-connection"
                  @click="binding(scope.row.userId)"
                >绑定
                </el-button>
              </template>
            </el-table-column>
          </el-table>
          <pagination
            v-show="total1>0"
            :total="total1"
            :page.sync="queryParams1.pageNum"
            :limit.sync="queryParams1.pageSize"
            @pagination="getAllUserList"
          />
        </el-col>
        <el-col :span="12">
          <el-tag type="warning">已绑定</el-tag>
          <div style="height: 10px"></div>
          <el-table v-loading="loading2" :data="bindingUserList" @selection-change="handleSelectionChange">
            <el-table-column label="用户编号" align="center" prop="userName"/>
            <el-table-column label="用户名" align="center" prop="nickName"/>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
              <template slot-scope="scope">
                <el-button
                  size="mini"
                  type="text"
                  icon="el-icon-close"
                  @click="untieUser(scope.row.userId)"
                >解绑
                </el-button>
              </template>
            </el-table-column>
          </el-table>
          <pagination
            v-show="total2>0"
            :total="total2"
            :page.sync="queryParams2.pageNum"
            :limit.sync="queryParams2.pageSize"
            @pagination="getBindingUserList"
          />
        </el-col>
      </el-row>
    </el-dialog>
    <el-dialog title="空开列表" v-dialogDrag :visible.sync="open2" width="65%" append-to-body>
      <UseNoConfig ref="unc" :useNoDeviceId="useNoDeviceId"></UseNoConfig>
    </el-dialog>
  </div>
</template>

<script>
import {
  addDevice,
  bindingUser,
  delDevice,
  exportDevice,
  getDevice,
  listAllDeviceUser,
  listBindingDeviceUser,
  listDevice,
  untieUser,
  updateDevice
} from "@/api/device/device";
import BaiduMapPoint from '../../../components/BaiduMap/baiduMapPoint'
import UseNoConfig from '../useNoConfig/index'
import user from "@/store/modules/user";
import {listPlace} from "@/api/canteen/place";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";

export default {
  name: "Device",
  components: {
    BaiduMapPoint,
    Treeselect,
    UseNoConfig
  },
  dicts: ['device_state'],
  data() {
    return {
      // 遮罩层
      loading: true,
      loading1: true,
      loading2: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      total1: 0,
      total2: 0,
      // device表格数据
      deviceList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      open1: false,
      open2: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        deviceNo: null,
        deviceOrgId: null,
        deviceUseId: null,
        deviceName: null,
        deviceInitCode: null,
        deviceIpAddr: null,
        deviceLocationAddr: null,
        deviceState: null,
        content: null,
        sort: null,
      },
      queryParams1: {
        pageNum: 1,
        pageSize: 10,
        userType: 11,
      },
      queryParams2: {
        pageNum: 1,
        pageSize: 10,
        userType: 11,
        deviceId: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        deviceNo: [
          {required: true, message: "设备编号不能为空", trigger: "blur"}
        ],
        deviceName: [
          {required: true, message: "设备名称不能为空", trigger: "blur"}
        ],
        deviceIpAddr: [
          {required: true, message: "设备IP地址不能为空", trigger: "blur"}
        ],
        deviceState: [
          {required: true, message: "设备状态不能为空", trigger: "blur"}
        ],
      },
      useNoDeviceId: '',
      bindingUserList: [],
      allUserList: []
    };
  },
  created() {
    this.getTreeSelect();
    this.getList();
  },
  methods: {
    /** 查询device列表 */
    getList() {
      this.queryParams.deviceOrgId = user.state.organ;
      this.loading = true;
      listDevice(this.queryParams).then(response => {
        this.deviceList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
      return this.deviceList;
    },
    /* 获取所有用户列表 */
    getAllUserList() {
      this.allUserList = []
      this.loading1 = true;
      listAllDeviceUser(this.queryParams1).then(response => {
          this.allUserList = response.rows;
          this.total1 = response.total;
          this.loading1 = false;
        }
      ).catch(reason => {
        this.loading1 = false;
      });
    },
    /* 获取绑定用户列表 */
    getBindingUserList() {
      this.bindingUserList = []
      this.loading2 = true;
      listBindingDeviceUser(this.queryParams2).then(response => {
          this.bindingUserList = response.rows;
          this.total2 = response.total;
          this.loading2 = false;
        }
      ).catch(reason => {
        this.loading2 = false;
      });
    },
    // 绑定按钮
    binding(id) {
      this.form.userId = id
      this.form.deviceId = this.queryParams2.deviceId
      bindingUser(this.form).then(re => {
        this.getBindingUserList()
      })
    },
    // 解绑按钮
    untieUser(id) {
      this.form.userId = id
      this.form.deviceId = this.queryParams2.deviceId
      untieUser(this.form).then(re => {
        this.getBindingUserList()
      })
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        deviceId: null,
        deviceNo: null,
        deviceOrgId: null,
        deviceUseId: null,
        deviceName: null,
        deviceInitCode: null,
        deviceIpAddr: null,
        deviceLocationAddr: null,
        deviceState: 0,
        expirationDate: null,
        sort: null,
        isDelete: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.deviceId)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加设备";
      this.form.deviceOrgId = user.state.organ;
    },
    /**
     * 绑定用户
     * */
    openBindingUsers(row) {
      this.queryParams2.deviceId = row.deviceId
      this.getAllUserList();
      this.getBindingUserList()
      this.open1 = true;
    },
    /**
     * 空开列表
     * */
    getDeviceUseNoList(row) {
      this.useNoDeviceId = row.deviceId
      this.$nextTick(_ => {
        this.$refs.unc.getList()
      })
      this.open2 = true;
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const deviceId = row.deviceId || this.ids
      getDevice(deviceId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改设备";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.deviceId != null) {
            updateDevice(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addDevice(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const deviceIds = row.deviceId || this.ids;
      this.$modal.confirm('是否确认删除device编号为"' + deviceIds + '"的数据项？').then(function () {
        return delDevice(deviceIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$modal.confirm('是否确认导出所有device数据项？').then(() => {
        this.exportLoading = true;
        return exportDevice(queryParams);
      }).then(response => {
        this.$download.name(response.msg);
        this.exportLoading = false;
      }).catch(() => {
      });
    },
    getTreeSelect() {
      listPlace({jgid: user.state.organ}).then(response => {
        this.placeOptions = [];
        const data = {placeId: 0, placeName: '顶级节点', children: []};
        data.children = this.handleTree(response.data, "placeId", "parentId");
        console.log(data);
        this.placeOptions.push(data);
      });
    }
  }
};
</script>
